@@ -71,6 +71,7 @@ done
 wait
 
 echo $targetFile
+cp $userpath/tmp3/target_comb_final_sort.tmp $userpath/log/target_comb_final_sort.tmp
 
 # annotate the regions by omics features
 for filename in $annoFile
@@ -93,5 +94,5 @@ rm -f $userpath/tmp3/*.tmp
 
 # merging all the annotations
 echo "--------------Merging features!-----------------"
-Rscript $basepath/Rscript/MergeFeature_complete.R  $1  $userpath/tmp3 $model $userpath/feature_out.txt
-
+Rscript $basepath/Rscript/MergeFeature_complete.R  $userpath/log/target_comb_final_sort.tmp  $userpath/tmp3 $model $userpath/feature_out.txt
+rm -f $userpath/log/*.tmp
\ No newline at end of file
